@@ -12,6 +12,11 @@ var urlCmd = &cobra.Command{
 	Short: "Use single target mode",
 	Run: func(cmd *cobra.Command, args []string) {
 		printing.Banner(options)
+		if len(args) == 0 {
+			printing.DalLog("ERROR", "Input target url", options)
+			printing.DalLog("ERROR", "e.g dalfox url https://google.com/?q=1", options)
+			return
+		}
 		printing.Summary(options, args[0])
 		if len(args) >= 1 {
 			printing.DalLog("SYSTEM", "Using single target mode", options)
