@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"io/ioutil"
 	"net/http"
+	"net/http/httputil"
 	"net/url"
 	"os"
 	"strconv"
@@ -12,6 +13,8 @@ import (
 	"sync"
 	"time"
 
+	"github.com/hahwul/dalfox/v2/pkg/har"
+
 	"golang.org/x/term"
 
 	"github.com/briandowns/spinner"
@@ -603,7 +606,7 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 				if endpoint == "portswigger" {
 					payload, line, size = getPortswiggerPayload()
 				}
-				if endpoint == "paylaodbox" {
+				if endpoint == "payloadbox" {
 					payload, line, size = getPayloadBoxPayload()
 				}
 				if line != "" {
@@ -694,7 +697,10 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 									CWE:        "CWE-79",
 									Severity:   "High",
 									PoCType:    options.PoCType,
+									MessageStr: "Triggered XSS Payload (found dialog in headless)",
+									//MessageID:  -1, // we can't do HAR here because it's using chromedp
 								}
+
 								if showV {
 									if options.Format == "json" {
 										pocj, _ := json.Marshal(poc)
@@ -777,9 +783,24 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 															CWE:        "CWE-79",
 															Severity:   "High",
 															PoCType:    options.PoCType,
+															MessageID:  har.MessageIDFromRequest(k),
+															MessageStr: "Triggered XSS Payload (found dialog in headless)",
 														}
 														poc.Data = MakePoC(poc.Data, k, options)
 
+														if options.OutputRequest {
+															reqDump, err := httputil.DumpRequestOut(k, true)
+															if err == nil {
+																poc.RawHTTPRequest = string(reqDump)
+																printing.DalLog("CODE", "\n"+string(reqDump), options)
+															}
+														}
+
+														if options.OutputResponse {
+															poc.RawHTTPResponse = resbody
+															printing.DalLog("CODE", string(resbody), options)
+														}
+
 														if showV {
 															if options.Format == "json" {
 																pocj, _ := json.Marshal(poc)
@@ -801,6 +822,7 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 														if options.FoundAction != "" {
 															foundAction(options, target, k.URL.String(), "WEAK")
 														}
+														printing.DalLog("WEAK", "Reflected Payload in JS: "+v["param"]+"="+v["payload"], options)
 														poc := model.PoC{
 															Type:       "R",
 															InjectType: v["type"],
@@ -812,8 +834,22 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 															CWE:        "CWE-79",
 															Severity:   "Medium",
 															PoCType:    options.PoCType,
+															MessageID:  har.MessageIDFromRequest(k),
+															MessageStr: "Reflected Payload in JS: " + v["param"] + "=" + v["payload"],
 														}
 														poc.Data = MakePoC(poc.Data, k, options)
+														if options.OutputRequest {
+															reqDump, err := httputil.DumpRequestOut(k, true)
+															if err == nil {
+																poc.RawHTTPRequest = string(reqDump)
+																printing.DalLog("CODE", "\n"+string(reqDump), options)
+															}
+														}
+
+														if options.OutputResponse {
+															poc.RawHTTPResponse = resbody
+															printing.DalLog("CODE", string(resbody), options)
+														}
 
 														scanObject.Results = append(scanObject.Results, poc)
 														scanResult.PoCs = append(scanResult.PoCs, poc)
@@ -835,8 +871,22 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 														CWE:        "CWE-79",
 														Severity:   "Medium",
 														PoCType:    options.PoCType,
+														MessageID:  har.MessageIDFromRequest(k),
+														MessageStr: "Reflected Payload in JS: " + v["param"] + "=" + v["payload"],
 													}
 													poc.Data = MakePoC(poc.Data, k, options)
+													if options.OutputRequest {
+														reqDump, err := httputil.DumpRequestOut(k, true)
+														if err == nil {
+															poc.RawHTTPRequest = string(reqDump)
+															printing.DalLog("CODE", "\n"+string(reqDump), options)
+														}
+													}
+
+													if options.OutputResponse {
+														poc.RawHTTPResponse = resbody
+														printing.DalLog("CODE", string(resbody), options)
+													}
 
 													if showR {
 														if options.Format == "json" {
@@ -875,8 +925,22 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 												CWE:        "CWE-83",
 												Severity:   "High",
 												PoCType:    options.PoCType,
+												MessageID:  har.MessageIDFromRequest(k),
+												MessageStr: "Triggered XSS Payload (found DOM Object): " + v["param"] + "=" + v["payload"],
 											}
 											poc.Data = MakePoC(poc.Data, k, options)
+											if options.OutputRequest {
+												reqDump, err := httputil.DumpRequestOut(k, true)
+												if err == nil {
+													poc.RawHTTPRequest = string(reqDump)
+													printing.DalLog("CODE", "\n"+string(reqDump), options)
+												}
+											}
+
+											if options.OutputResponse {
+												poc.RawHTTPResponse = resbody
+												printing.DalLog("CODE", string(resbody), options)
+											}
 
 											if showV {
 												if options.Format == "json" {
@@ -912,8 +976,22 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 												CWE:        "CWE-83",
 												Severity:   "Medium",
 												PoCType:    options.PoCType,
+												MessageID:  har.MessageIDFromRequest(k),
+												MessageStr: "Reflected Payload in Attribute: " + v["param"] + "=" + v["payload"],
 											}
 											poc.Data = MakePoC(poc.Data, k, options)
+											if options.OutputRequest {
+												reqDump, err := httputil.DumpRequestOut(k, true)
+												if err == nil {
+													poc.RawHTTPRequest = string(reqDump)
+													printing.DalLog("CODE", "\n"+string(reqDump), options)
+												}
+											}
+
+											if options.OutputResponse {
+												poc.RawHTTPResponse = resbody
+												printing.DalLog("CODE", string(resbody), options)
+											}
 
 											if showR {
 												if options.Format == "json" {
@@ -950,8 +1028,22 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 												CWE:        "CWE-79",
 												Severity:   "High",
 												PoCType:    options.PoCType,
+												MessageID:  har.MessageIDFromRequest(k),
+												MessageStr: "Triggered XSS Payload (found DOM Object): " + v["param"] + "=" + v["payload"],
 											}
 											poc.Data = MakePoC(poc.Data, k, options)
+											if options.OutputRequest {
+												reqDump, err := httputil.DumpRequestOut(k, true)
+												if err == nil {
+													poc.RawHTTPRequest = string(reqDump)
+													printing.DalLog("CODE", "\n"+string(reqDump), options)
+												}
+											}
+
+											if options.OutputResponse {
+												poc.RawHTTPResponse = resbody
+												printing.DalLog("CODE", string(resbody), options)
+											}
 
 											if showV {
 												if options.Format == "json" {
@@ -987,8 +1079,22 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 												CWE:        "CWE-79",
 												Severity:   "Medium",
 												PoCType:    options.PoCType,
+												MessageID:  har.MessageIDFromRequest(k),
+												MessageStr: "Reflected Payload in HTML: " + v["param"] + "=" + v["payload"],
 											}
 											poc.Data = MakePoC(poc.Data, k, options)
+											if options.OutputRequest {
+												reqDump, err := httputil.DumpRequestOut(k, true)
+												if err == nil {
+													poc.RawHTTPRequest = string(reqDump)
+													printing.DalLog("CODE", "\n"+string(reqDump), options)
+												}
+											}
+
+											if options.OutputResponse {
+												poc.RawHTTPResponse = resbody
+												printing.DalLog("CODE", string(resbody), options)
+											}
 
 											if showR {
 												if options.Format == "json" {
