@@ -7,10 +7,13 @@ import (
 	"io"
 	"io/ioutil"
 	"net/http"
+	"net/http/httputil"
 	"strconv"
 	"strings"
 	"time"
 
+	"github.com/hahwul/dalfox/v2/pkg/har"
+
 	"github.com/hahwul/dalfox/v2/pkg/model"
 	"github.com/hahwul/dalfox/v2/pkg/optimization"
 	"github.com/hahwul/dalfox/v2/pkg/printing"
@@ -54,7 +57,17 @@ func SendReq(req *http.Request, payload string, options model.Options) (string,
 					CWE:        "CWE-601",
 					Severity:   "Medium",
 					PoCType:    options.PoCType,
+					MessageID:  har.MessageIDFromRequest(req),
+					MessageStr: "Found Open Redirect. Payload: " + via[0].URL.String(),
 				}
+				if options.OutputRequest {
+					reqDump, err := httputil.DumpRequestOut(req, true)
+					if err == nil {
+						poc.RawHTTPRequest = string(reqDump)
+						printing.DalLog("CODE", "\n"+string(reqDump), options)
+					}
+				}
+
 				if showG {
 					if options.Format == "json" {
 						pocj, _ := json.Marshal(poc)
@@ -111,14 +124,29 @@ func SendReq(req *http.Request, payload string, options model.Options) (string,
 					CWE:        "CWE-93",
 					Severity:   "Medium",
 					PoCType:    options.PoCType,
+					MessageID:  har.MessageIDFromRequest(req),
 				}
 				poc.Data = MakePoC(poc.Data, req, options)
+				if options.OutputRequest {
+					reqDump, err := httputil.DumpRequestOut(req, true)
+					if err == nil {
+						poc.RawHTTPRequest = string(reqDump)
+						printing.DalLog("CODE", "\n"+string(reqDump), options)
+					}
+				}
+
+				if options.OutputResponse {
+					poc.RawHTTPResponse = str
+					printing.DalLog("CODE", string(str), options)
+				}
 
 				if !duplicatedResult(scanObject.Results, poc) {
 					if payload != "" {
 						printing.DalLog("GREP", "Found CRLF Injection via built-in grepping / payload: "+payload, options)
+						poc.MessageStr = "Found CRLF Injection via built-in grepping / payload: " + payload
 					} else {
 						printing.DalLog("GREP", "Found CRLF Injection via built-in grepping / original request", options)
+						poc.MessageStr = "Found CRLF Injection via built-in grepping / original request"
 					}
 					if options.FoundAction != "" {
 						foundAction(options, req.URL.Host, poc.Data, "BAV: "+poc.InjectType)
@@ -160,14 +188,29 @@ func SendReq(req *http.Request, payload string, options model.Options) (string,
 						CWE:        "CWE-94",
 						Severity:   "High",
 						PoCType:    options.PoCType,
+						MessageID:  har.MessageIDFromRequest(req),
 					}
 					poc.Data = MakePoC(poc.Data, req, options)
+					if options.OutputRequest {
+						reqDump, err := httputil.DumpRequestOut(req, true)
+						if err == nil {
+							poc.RawHTTPRequest = string(reqDump)
+							printing.DalLog("CODE", "\n"+string(reqDump), options)
+						}
+					}
+
+					if options.OutputResponse {
+						poc.RawHTTPResponse = str
+						printing.DalLog("CODE", string(str), options)
+					}
 
 					if !duplicatedResult(scanObject.Results, poc) {
 						if payload != "" {
 							printing.DalLog("GREP", "Found SSTI via built-in grepping / payload: "+payload, options)
+							poc.MessageStr = "Found SSTI via built-in grepping / payload: " + payload
 						} else {
 							printing.DalLog("GREP", "Found SSTI via built-in grepping / original request", options)
+							poc.MessageStr = "Found SSTI via built-in grepping / original request"
 						}
 
 						if options.FoundAction != "" {
@@ -202,14 +245,29 @@ func SendReq(req *http.Request, payload string, options model.Options) (string,
 					CWE:        "",
 					Severity:   "Low",
 					PoCType:    options.PoCType,
+					MessageID:  har.MessageIDFromRequest(req),
 				}
 				poc.Data = MakePoC(poc.Data, req, options)
+				if options.OutputRequest {
+					reqDump, err := httputil.DumpRequestOut(req, true)
+					if err == nil {
+						poc.RawHTTPRequest = string(reqDump)
+						printing.DalLog("CODE", "\n"+string(reqDump), options)
+					}
+				}
+
+				if options.OutputResponse {
+					poc.RawHTTPResponse = str
+					printing.DalLog("CODE", string(str), options)
+				}
 
 				if !duplicatedResult(scanObject.Results, poc) {
 					if payload != "" {
 						printing.DalLog("GREP", "Found "+k+" via built-in grepping / payload: "+payload, options)
+						poc.MessageStr = "Found " + k + " via built-in grepping / payload: " + payload
 					} else {
 						printing.DalLog("GREP", "Found "+k+" via built-in grepping / original request", options)
+						poc.MessageStr = "Found " + k + " via built-in grepping / original request"
 					}
 
 					if options.FoundAction != "" {
@@ -253,11 +311,25 @@ func SendReq(req *http.Request, payload string, options model.Options) (string,
 					CWE:        "",
 					Severity:   "Low",
 					PoCType:    options.PoCType,
+					MessageID:  har.MessageIDFromRequest(req),
 				}
 				poc.Data = MakePoC(poc.Data, req, options)
+				if options.OutputRequest {
+					reqDump, err := httputil.DumpRequestOut(req, true)
+					if err == nil {
+						poc.RawHTTPRequest = string(reqDump)
+						printing.DalLog("CODE", "\n"+string(reqDump), options)
+					}
+				}
+
+				if options.OutputResponse {
+					poc.RawHTTPResponse = str
+					printing.DalLog("CODE", string(str), options)
+				}
 
 				if !duplicatedResult(scanObject.Results, poc) {
 					printing.DalLog("GREP", "Found "+k+" via custom grepping / payload: "+payload, options)
+					poc.MessageStr = "Found " + k + " via custom grepping / payload: " + payload
 					for _, vv := range v {
 						printing.DalLog("CODE", vv, options)
 					}
